### A Pluto.jl notebook ###
# v0.19.46

using Markdown
using InteractiveUtils

# This Pluto notebook uses @bind for interactivity. When running this notebook outside of Pluto, the following 'mock version' of @bind gives bound variables a default value (instead of an error).
macro bind(def, element)
    quote
        local iv = try Base.loaded_modules[Base.PkgId(Base.UUID("6e696c72-6542-2067-7265-42206c756150"), "AbstractPlutoDingetjes")].Bonds.initial_value catch; b -> missing; end
        local el = $(esc(element))
        global $(esc(def)) = Core.applicable(Base.get, el) ? Base.get(el) : iv(el)
        el
    end
end

# ╔═╡ d3c95316-7ffb-11ef-1e2c-2934f89a2336
begin
	using PlutoUI
	using HypertextLiteral: @htl
	using SQLite
	using DBInterface
	using DataFrames
	using Dates
end

# ╔═╡ 33b70516-7687-463b-a654-2cde3f2538aa
md"""
# 試験結果一覧の取得
"""

# ╔═╡ 15d55f6e-b8ce-4916-a8fa-c9b07b0cc86a
md"""
PSBoard idを入力: $(@bind psbid NumberField(0:999999, default = 164))
"""

# ╔═╡ 8440a1de-12fe-4bb7-907f-52f933934ec0
md"""
1回試験
"""

# ╔═╡ 0299d5b7-8b9f-44ae-a2cf-3db36e1f857a
md"""
100回試験
"""

# ╔═╡ 7a11e460-8d6f-454c-8fe6-33c59eeb4937
md"""
run
"""

# ╔═╡ 1287b479-cce9-4eb1-949b-9da7d0329c24
md"""
出荷状況
""";

# ╔═╡ 1d90c687-7e67-43ed-b5bf-68ef9040dc95
md"""
# 100回じゃない試験
"""

# ╔═╡ ec2d40f7-1e06-414d-9a77-9e3489ba271c
md"""
# その他コード
"""

# ╔═╡ 31b74828-fdc7-4b04-8be0-ea44820f9555
TableOfContents()

# ╔═╡ bb167a5e-b23a-4f05-9ba6-368a48f9c120
# @htl("""
# <style>
# 	@media screen {
# 		main {
# 			margin: 0 auto;
# 			max-width: 1000px;
# 			padding-left: max(160px, 10%);
# 			padding-right: max(160px, 10%);
# 		}
# 	}
# </style>
# """)

# ╔═╡ 3a1aa3d8-bea0-46cb-b07e-88e9484e75c6
function cols_visibility_toggle(df)
	cols = names(df)
	single_show_cols = Dict(cols .=> fill(true, length(cols)))
	PlutoUI.combine() do Child
		@htl("""
			<table>
				<tr>
					<th> コラム </th>
					<th> 表示 </th>
				</tr>
				$([
					@htl("""
						<tr>
							<td> $(name) </td>
							<td> $(Child(CheckBox(default = true))) </td>
						</tr>
					""")
						for name in cols
				])
			</table>
		""")
	end
end

# ╔═╡ 4d62900a-0810-49d1-8632-a9e7544f381b
db = SQLite.DB("../psboard_qaqc.db")

# ╔═╡ 911a5ae8-5800-4d20-9d73-bcc7205d3501
SQLite.tables(db)

# ╔═╡ 6da1efbe-e5a0-4376-b8ea-ed21f09da084
qaqc_single_result = DBInterface.execute(
	db,
	sql"""
	select * from qaqc_single_run_results
	"""
) |> DataFrame

# ╔═╡ a85b4f19-82e4-40d5-af9f-d5286578b1fb
@bind single_result_for_id_show_cols cols_visibility_toggle(qaqc_single_result)

# ╔═╡ 9513f017-7905-495d-a7eb-6ca5927308dd
single_result_for_id = filter(
	:psboard_id => ==(psbid),
	qaqc_single_result,
);

# ╔═╡ 23167971-4671-4f18-84df-72a7dc5938e1
qaqc_positions = DBInterface.execute(
	db,
	sql"""
	select * from qaqc_positions
	"""
) |> DataFrame

# ╔═╡ 192c47a3-7202-4351-8638-ec49ecb901c5
single_result_for_id_show = let
	df = leftjoin(
		single_result_for_id,
		qaqc_positions[:, [:id, :name]],
		on = :position => :id,
	)[:, Not(:position)]
	rename!(df, :name => :position)
	df
end;

# ╔═╡ a7c1ae88-34dc-445c-ad2c-3879192d13c7
single_result_for_id_show[!, collect(single_result_for_id_show_cols)]

# ╔═╡ 62ddeb91-e007-4407-b4dc-1b7392480781
qaqc_runs = let
	df = DBInterface.execute(
		db,
		sql"""
		select * from qaqc_runs
		"""
	) |> DataFrame
	transform!(df, :run_datetime => ByRow(passmissing(DateTime)) => :run_datetime)
	transform!(
		df,
		:shiftscript_ver => ByRow(passmissing(VersionNumber)) => :shiftscript_ver
	)
	df
end

# ╔═╡ a77ccf6b-db67-4a07-833a-210afccc39e5
qaqc_extra_run_results = DBInterface.execute(
	db,
	sql"""
	select * from qaqc_extra_run_results
	"""
) |> DataFrame

# ╔═╡ 1e9ab6b0-b25d-44ad-92ae-f12f92d91d5e
extra_result_for_id = filter(
	:psboard_id => ==(psbid),
	qaqc_extra_run_results,
);

# ╔═╡ ed7c40fe-f966-4afb-a962-896c9f109946
filter(
	:id => ∈([single_result_for_id.runid; extra_result_for_id.runid;]),
	qaqc_runs
)

# ╔═╡ 51370abb-f0fb-4ae0-b488-bf9fc776577c
extra_result_for_id_show = let
	df = leftjoin(
		extra_result_for_id,
		qaqc_positions[:, [:id, :name]],
		on = :position => :id,
	)[:, Not(:position)]
	rename!(df, :name => :position)
	df
end;

# ╔═╡ 45828bb4-e9f5-46d5-8f48-88284f318cc4
@bind extra_result_for_id_show_cols cols_visibility_toggle(extra_result_for_id_show)

# ╔═╡ 6ceb198e-edd3-4954-b1ff-beef33c3f205
extra_result_for_id_show[!, collect(extra_result_for_id_show_cols)]

# ╔═╡ 0518af44-878e-4052-b4d4-e7fb3c35efea
let
	df = filter(
		:num_tests => !=(100),
		qaqc_extra_run_results,
	)
	unique!(df, :runid).runid
end

# ╔═╡ e312d48d-9d8d-4f42-b134-7fe3023df270
qaqc_resistance_check = let
	df = DBInterface.execute(
		db,
		sql"""
		select * from qaqc_resistance_check
		"""
	) |> DataFrame
	transform!(
		df,
		:passed => ByRow(Bool) => :passed
	)
	df
end

# ╔═╡ 79703745-6c0e-4201-a58d-e75994fab4e4
qaqc_dispatch = DBInterface.execute(
	db,
	sql"""
	select * from qaqc_dispatch
	"""
) |> DataFrame

# ╔═╡ b53ede8c-414e-40b5-8f30-fedf47a530ac
let
	passed = filter(
		:psb_id => ==(psbid),
		qaqc_resistance_check
	).passed
	resistance_status = if isempty(passed)
		""
	elseif all(passed)
		"OK"
	else
		"FAIL"
	end
	dispatch_status = let
		if combine(
			qaqc_dispatch,
			:psb_id => (v -> any(==(psbid), v)) => :dispatched
		).dispatched |> first
			"済"
		else
			"未"
		end
	end
	md"""
	抵抗値テスト: $(resistance_status) \
	出荷状況: $(dispatch_status)
	"""
end

# ╔═╡ 199b45f6-1e63-4392-af6a-6a5ed83bf467
filter(
	:psb_id => ==(psbid),
	qaqc_dispatch
);

# ╔═╡ 00000000-0000-0000-0000-000000000001
PLUTO_PROJECT_TOML_CONTENTS = """
[deps]
DBInterface = "a10d1c49-ce27-4219-8d33-6db1a4562965"
DataFrames = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
Dates = "ade2ca70-3891-5945-98fb-dc099432e06a"
HypertextLiteral = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
PlutoUI = "7f904dfe-b85e-4ff6-b463-dae2292396a8"
SQLite = "0aa819cd-b072-5ff4-a722-6bc24af294d9"

[compat]
DBInterface = "~2.6.1"
DataFrames = "~1.7.0"
HypertextLiteral = "~0.9.5"
PlutoUI = "~0.7.60"
SQLite = "~1.6.1"
"""

# ╔═╡ 00000000-0000-0000-0000-000000000002
PLUTO_MANIFEST_TOML_CONTENTS = """
# This file is machine-generated - editing it directly is not advised

julia_version = "1.10.5"
manifest_format = "2.0"
project_hash = "f94b8dc124480c7dc21fffae2618aeb81f5d3237"

[[deps.AbstractPlutoDingetjes]]
deps = ["Pkg"]
git-tree-sha1 = "6e1d2a35f2f90a4bc7c2ed98079b2ba09c35b83a"
uuid = "6e696c72-6542-2067-7265-42206c756150"
version = "1.3.2"

[[deps.ArgTools]]
uuid = "0dad84c5-d112-42e6-8d28-ef12dabb789f"
version = "1.1.1"

[[deps.Artifacts]]
uuid = "56f22d72-fd6d-98f1-02f0-08ddc0907c33"

[[deps.Base64]]
uuid = "2a0f44e3-6c83-55bd-87e4-b1978d98bd5f"

[[deps.ColorTypes]]
deps = ["FixedPointNumbers", "Random"]
git-tree-sha1 = "b10d0b65641d57b8b4d5e234446582de5047050d"
uuid = "3da002f7-5984-5a60-b8a6-cbb66c0b333f"
version = "0.11.5"

[[deps.Compat]]
deps = ["TOML", "UUIDs"]
git-tree-sha1 = "8ae8d32e09f0dcf42a36b90d4e17f5dd2e4c4215"
uuid = "34da2185-b29b-5c13-b0c7-acf172513d20"
version = "4.16.0"
weakdeps = ["Dates", "LinearAlgebra"]

    [deps.Compat.extensions]
    CompatLinearAlgebraExt = "LinearAlgebra"

[[deps.CompilerSupportLibraries_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "e66e0078-7015-5450-92f7-15fbd957f2ae"
version = "1.1.1+0"

[[deps.Crayons]]
git-tree-sha1 = "249fe38abf76d48563e2f4556bebd215aa317e15"
uuid = "a8cc5b0e-0ffa-5ad4-8c14-923d3ee1735f"
version = "4.1.1"

[[deps.DBInterface]]
git-tree-sha1 = "a444404b3f94deaa43ca2a58e18153a82695282b"
uuid = "a10d1c49-ce27-4219-8d33-6db1a4562965"
version = "2.6.1"

[[deps.DataAPI]]
git-tree-sha1 = "abe83f3a2f1b857aac70ef8b269080af17764bbe"
uuid = "9a962f9c-6df0-11e9-0e5d-c546b8b5ee8a"
version = "1.16.0"

[[deps.DataFrames]]
deps = ["Compat", "DataAPI", "DataStructures", "Future", "InlineStrings", "InvertedIndices", "IteratorInterfaceExtensions", "LinearAlgebra", "Markdown", "Missings", "PooledArrays", "PrecompileTools", "PrettyTables", "Printf", "Random", "Reexport", "SentinelArrays", "SortingAlgorithms", "Statistics", "TableTraits", "Tables", "Unicode"]
git-tree-sha1 = "fb61b4812c49343d7ef0b533ba982c46021938a6"
uuid = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
version = "1.7.0"

[[deps.DataStructures]]
deps = ["Compat", "InteractiveUtils", "OrderedCollections"]
git-tree-sha1 = "1d0a14036acb104d9e89698bd408f63ab58cdc82"
uuid = "864edb3b-99cc-5e75-8d2d-829cb0a9cfe8"
version = "0.18.20"

[[deps.DataValueInterfaces]]
git-tree-sha1 = "bfc1187b79289637fa0ef6d4436ebdfe6905cbd6"
uuid = "e2d170a0-9d28-54be-80f0-106bbe20a464"
version = "1.0.0"

[[deps.Dates]]
deps = ["Printf"]
uuid = "ade2ca70-3891-5945-98fb-dc099432e06a"

[[deps.Downloads]]
deps = ["ArgTools", "FileWatching", "LibCURL", "NetworkOptions"]
uuid = "f43a241f-c20a-4ad4-852c-f6b1247861c6"
version = "1.6.0"

[[deps.FileWatching]]
uuid = "7b1f6079-737a-58dc-b8bc-7a2ca5c1b5ee"

[[deps.FixedPointNumbers]]
deps = ["Statistics"]
git-tree-sha1 = "05882d6995ae5c12bb5f36dd2ed3f61c98cbb172"
uuid = "53c48c17-4a7d-5ca2-90c5-79b7896eea93"
version = "0.8.5"

[[deps.Future]]
deps = ["Random"]
uuid = "9fa8497b-333b-5362-9e8d-4d0656e87820"

[[deps.Hyperscript]]
deps = ["Test"]
git-tree-sha1 = "179267cfa5e712760cd43dcae385d7ea90cc25a4"
uuid = "47d2ed2b-36de-50cf-bf87-49c2cf4b8b91"
version = "0.0.5"

[[deps.HypertextLiteral]]
deps = ["Tricks"]
git-tree-sha1 = "7134810b1afce04bbc1045ca1985fbe81ce17653"
uuid = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
version = "0.9.5"

[[deps.IOCapture]]
deps = ["Logging", "Random"]
git-tree-sha1 = "b6d6bfdd7ce25b0f9b2f6b3dd56b2673a66c8770"
uuid = "b5f81e59-6552-4d32-b1f0-c071b021bf89"
version = "0.2.5"

[[deps.InlineStrings]]
git-tree-sha1 = "45521d31238e87ee9f9732561bfee12d4eebd52d"
uuid = "842dd82b-1e85-43dc-bf29-5d0ee9dffc48"
version = "1.4.2"

    [deps.InlineStrings.extensions]
    ArrowTypesExt = "ArrowTypes"
    ParsersExt = "Parsers"

    [deps.InlineStrings.weakdeps]
    ArrowTypes = "31f734f8-188a-4ce0-8406-c8a06bd891cd"
    Parsers = "69de0a69-1ddd-5017-9359-2bf0b02dc9f0"

[[deps.InteractiveUtils]]
deps = ["Markdown"]
uuid = "b77e0a4c-d291-57a0-90e8-8db25a27a240"

[[deps.InvertedIndices]]
git-tree-sha1 = "0dc7b50b8d436461be01300fd8cd45aa0274b038"
uuid = "41ab1584-1d38-5bbf-9106-f11c6c58b48f"
version = "1.3.0"

[[deps.IteratorInterfaceExtensions]]
git-tree-sha1 = "a3f24677c21f5bbe9d2a714f95dcd58337fb2856"
uuid = "82899510-4779-5014-852e-03e436cf321d"
version = "1.0.0"

[[deps.JLLWrappers]]
deps = ["Artifacts", "Preferences"]
git-tree-sha1 = "f389674c99bfcde17dc57454011aa44d5a260a40"
uuid = "692b3bcd-3c85-4b1f-b108-f13ce0eb3210"
version = "1.6.0"

[[deps.JSON]]
deps = ["Dates", "Mmap", "Parsers", "Unicode"]
git-tree-sha1 = "31e996f0a15c7b280ba9f76636b3ff9e2ae58c9a"
uuid = "682c06a0-de6a-54ab-a142-c8b1cf79cde6"
version = "0.21.4"

[[deps.LaTeXStrings]]
git-tree-sha1 = "50901ebc375ed41dbf8058da26f9de442febbbec"
uuid = "b964fa9f-0449-5b57-a5c2-d3ea65f4040f"
version = "1.3.1"

[[deps.LibCURL]]
deps = ["LibCURL_jll", "MozillaCACerts_jll"]
uuid = "b27032c2-a3e7-50c8-80cd-2d36dbcbfd21"
version = "0.6.4"

[[deps.LibCURL_jll]]
deps = ["Artifacts", "LibSSH2_jll", "Libdl", "MbedTLS_jll", "Zlib_jll", "nghttp2_jll"]
uuid = "deac9b47-8bc7-5906-a0fe-35ac56dc84c0"
version = "8.4.0+0"

[[deps.LibGit2]]
deps = ["Base64", "LibGit2_jll", "NetworkOptions", "Printf", "SHA"]
uuid = "76f85450-5226-5b5a-8eaa-529ad045b433"

[[deps.LibGit2_jll]]
deps = ["Artifacts", "LibSSH2_jll", "Libdl", "MbedTLS_jll"]
uuid = "e37daf67-58a4-590a-8e99-b0245dd2ffc5"
version = "1.6.4+0"

[[deps.LibSSH2_jll]]
deps = ["Artifacts", "Libdl", "MbedTLS_jll"]
uuid = "29816b5a-b9ab-546f-933c-edad1886dfa8"
version = "1.11.0+1"

[[deps.Libdl]]
uuid = "8f399da3-3557-5675-b5ff-fb832c97cbdb"

[[deps.LinearAlgebra]]
deps = ["Libdl", "OpenBLAS_jll", "libblastrampoline_jll"]
uuid = "37e2e46d-f89d-539d-b4ee-838fcccc9c8e"

[[deps.Logging]]
uuid = "56ddb016-857b-54e1-b83d-db4d58db5568"

[[deps.MIMEs]]
git-tree-sha1 = "65f28ad4b594aebe22157d6fac869786a255b7eb"
uuid = "6c6e2e6c-3030-632d-7369-2d6c69616d65"
version = "0.1.4"

[[deps.Markdown]]
deps = ["Base64"]
uuid = "d6f4376e-aef5-505a-96c1-9c027394607a"

[[deps.MbedTLS_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "c8ffd9c3-330d-5841-b78e-0817d7145fa1"
version = "2.28.2+1"

[[deps.Missings]]
deps = ["DataAPI"]
git-tree-sha1 = "ec4f7fbeab05d7747bdf98eb74d130a2a2ed298d"
uuid = "e1d29d7a-bbdc-5cf2-9ac0-f12de2c33e28"
version = "1.2.0"

[[deps.Mmap]]
uuid = "a63ad114-7e13-5084-954f-fe012c677804"

[[deps.MozillaCACerts_jll]]
uuid = "14a3606d-f60d-562e-9121-12d972cd8159"
version = "2023.1.10"

[[deps.NetworkOptions]]
uuid = "ca575930-c2e3-43a9-ace4-1e988b2c1908"
version = "1.2.0"

[[deps.OpenBLAS_jll]]
deps = ["Artifacts", "CompilerSupportLibraries_jll", "Libdl"]
uuid = "4536629a-c528-5b80-bd46-f80d51c5b363"
version = "0.3.23+4"

[[deps.OrderedCollections]]
git-tree-sha1 = "dfdf5519f235516220579f949664f1bf44e741c5"
uuid = "bac558e1-5e72-5ebc-8fee-abe8a469f55d"
version = "1.6.3"

[[deps.Parsers]]
deps = ["Dates", "PrecompileTools", "UUIDs"]
git-tree-sha1 = "8489905bcdbcfac64d1daa51ca07c0d8f0283821"
uuid = "69de0a69-1ddd-5017-9359-2bf0b02dc9f0"
version = "2.8.1"

[[deps.Pkg]]
deps = ["Artifacts", "Dates", "Downloads", "FileWatching", "LibGit2", "Libdl", "Logging", "Markdown", "Printf", "REPL", "Random", "SHA", "Serialization", "TOML", "Tar", "UUIDs", "p7zip_jll"]
uuid = "44cfe95a-1eb2-52ea-b672-e2afdf69b78f"
version = "1.10.0"

[[deps.PlutoUI]]
deps = ["AbstractPlutoDingetjes", "Base64", "ColorTypes", "Dates", "FixedPointNumbers", "Hyperscript", "HypertextLiteral", "IOCapture", "InteractiveUtils", "JSON", "Logging", "MIMEs", "Markdown", "Random", "Reexport", "URIs", "UUIDs"]
git-tree-sha1 = "eba4810d5e6a01f612b948c9fa94f905b49087b0"
uuid = "7f904dfe-b85e-4ff6-b463-dae2292396a8"
version = "0.7.60"

[[deps.PooledArrays]]
deps = ["DataAPI", "Future"]
git-tree-sha1 = "36d8b4b899628fb92c2749eb488d884a926614d3"
uuid = "2dfb63ee-cc39-5dd5-95bd-886bf059d720"
version = "1.4.3"

[[deps.PrecompileTools]]
deps = ["Preferences"]
git-tree-sha1 = "5aa36f7049a63a1528fe8f7c3f2113413ffd4e1f"
uuid = "aea7be01-6a6a-4083-8856-8a6e6704d82a"
version = "1.2.1"

[[deps.Preferences]]
deps = ["TOML"]
git-tree-sha1 = "9306f6085165d270f7e3db02af26a400d580f5c6"
uuid = "21216c6a-2e73-6563-6e65-726566657250"
version = "1.4.3"

[[deps.PrettyTables]]
deps = ["Crayons", "LaTeXStrings", "Markdown", "PrecompileTools", "Printf", "Reexport", "StringManipulation", "Tables"]
git-tree-sha1 = "1101cd475833706e4d0e7b122218257178f48f34"
uuid = "08abe8d2-0d0c-5749-adfa-8a2ac140af0d"
version = "2.4.0"

[[deps.Printf]]
deps = ["Unicode"]
uuid = "de0858da-6303-5e67-8744-51eddeeeb8d7"

[[deps.REPL]]
deps = ["InteractiveUtils", "Markdown", "Sockets", "Unicode"]
uuid = "3fa0cd96-eef1-5676-8a61-b3b8758bbffb"

[[deps.Random]]
deps = ["SHA"]
uuid = "9a3f8284-a2c9-5f02-9a11-845980a1fd5c"

[[deps.Reexport]]
git-tree-sha1 = "45e428421666073eab6f2da5c9d310d99bb12f9b"
uuid = "189a3867-3050-52da-a836-e630ba90ab69"
version = "1.2.2"

[[deps.SHA]]
uuid = "ea8e919c-243c-51af-8825-aaa63cd721ce"
version = "0.7.0"

[[deps.SQLite]]
deps = ["DBInterface", "Random", "SQLite_jll", "Serialization", "Tables", "WeakRefStrings"]
git-tree-sha1 = "38b82dbc52b7db40bea182688c7a1103d06948a4"
uuid = "0aa819cd-b072-5ff4-a722-6bc24af294d9"
version = "1.6.1"

[[deps.SQLite_jll]]
deps = ["Artifacts", "JLLWrappers", "Libdl", "Zlib_jll"]
git-tree-sha1 = "004fffbe2711abdc7263a980bbb1af9620781dd9"
uuid = "76ed43ae-9a5d-5a62-8c75-30186b810ce8"
version = "3.45.3+0"

[[deps.SentinelArrays]]
deps = ["Dates", "Random"]
git-tree-sha1 = "ff11acffdb082493657550959d4feb4b6149e73a"
uuid = "91c51154-3ec4-41a3-a24f-3f23e20d615c"
version = "1.4.5"

[[deps.Serialization]]
uuid = "9e88b42a-f829-5b0c-bbe9-9e923198166b"

[[deps.Sockets]]
uuid = "6462fe0b-24de-5631-8697-dd941f90decc"

[[deps.SortingAlgorithms]]
deps = ["DataStructures"]
git-tree-sha1 = "66e0a8e672a0bdfca2c3f5937efb8538b9ddc085"
uuid = "a2af1166-a08f-5f64-846c-94a0d3cef48c"
version = "1.2.1"

[[deps.SparseArrays]]
deps = ["Libdl", "LinearAlgebra", "Random", "Serialization", "SuiteSparse_jll"]
uuid = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"
version = "1.10.0"

[[deps.Statistics]]
deps = ["LinearAlgebra", "SparseArrays"]
uuid = "10745b16-79ce-11e8-11f9-7d13ad32a3b2"
version = "1.10.0"

[[deps.StringManipulation]]
deps = ["PrecompileTools"]
git-tree-sha1 = "a6b1675a536c5ad1a60e5a5153e1fee12eb146e3"
uuid = "892a3eda-7b42-436c-8928-eab12a02cf0e"
version = "0.4.0"

[[deps.SuiteSparse_jll]]
deps = ["Artifacts", "Libdl", "libblastrampoline_jll"]
uuid = "bea87d4a-7f5b-5778-9afe-8cc45184846c"
version = "7.2.1+1"

[[deps.TOML]]
deps = ["Dates"]
uuid = "fa267f1f-6049-4f14-aa54-33bafae1ed76"
version = "1.0.3"

[[deps.TableTraits]]
deps = ["IteratorInterfaceExtensions"]
git-tree-sha1 = "c06b2f539df1c6efa794486abfb6ed2022561a39"
uuid = "3783bdb8-4a98-5b6b-af9a-565f29a5fe9c"
version = "1.0.1"

[[deps.Tables]]
deps = ["DataAPI", "DataValueInterfaces", "IteratorInterfaceExtensions", "OrderedCollections", "TableTraits"]
git-tree-sha1 = "598cd7c1f68d1e205689b1c2fe65a9f85846f297"
uuid = "bd369af6-aec1-5ad0-b16a-f7cc5008161c"
version = "1.12.0"

[[deps.Tar]]
deps = ["ArgTools", "SHA"]
uuid = "a4e569a6-e804-4fa4-b0f3-eef7a1d5b13e"
version = "1.10.0"

[[deps.Test]]
deps = ["InteractiveUtils", "Logging", "Random", "Serialization"]
uuid = "8dfed614-e22c-5e08-85e1-65c5234f0b40"

[[deps.Tricks]]
git-tree-sha1 = "7822b97e99a1672bfb1b49b668a6d46d58d8cbcb"
uuid = "410a4b4d-49e4-4fbc-ab6d-cb71b17b3775"
version = "0.1.9"

[[deps.URIs]]
git-tree-sha1 = "67db6cc7b3821e19ebe75791a9dd19c9b1188f2b"
uuid = "5c2747f8-b7ea-4ff2-ba2e-563bfd36b1d4"
version = "1.5.1"

[[deps.UUIDs]]
deps = ["Random", "SHA"]
uuid = "cf7118a7-6976-5b1a-9a39-7adc72f591a4"

[[deps.Unicode]]
uuid = "4ec0a83e-493e-50e2-b9ac-8f72acf5a8f5"

[[deps.WeakRefStrings]]
deps = ["DataAPI", "InlineStrings", "Parsers"]
git-tree-sha1 = "b1be2855ed9ed8eac54e5caff2afcdb442d52c23"
uuid = "ea10d353-3f73-51f8-a26c-33c1cb351aa5"
version = "1.4.2"

[[deps.Zlib_jll]]
deps = ["Libdl"]
uuid = "83775a58-1f1d-513f-b197-d71354ab007a"
version = "1.2.13+1"

[[deps.libblastrampoline_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "8e850b90-86db-534c-a0d3-1478176c7d93"
version = "5.11.0+0"

[[deps.nghttp2_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "8e850ede-7688-5339-a07c-302acd2aaf8d"
version = "1.52.0+1"

[[deps.p7zip_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "3f19e933-33d8-53b3-aaab-bd5110c3b7a0"
version = "17.4.0+2"
"""

# ╔═╡ Cell order:
# ╟─33b70516-7687-463b-a654-2cde3f2538aa
# ╟─15d55f6e-b8ce-4916-a8fa-c9b07b0cc86a
# ╟─b53ede8c-414e-40b5-8f30-fedf47a530ac
# ╟─8440a1de-12fe-4bb7-907f-52f933934ec0
# ╟─a7c1ae88-34dc-445c-ad2c-3879192d13c7
# ╟─0299d5b7-8b9f-44ae-a2cf-3db36e1f857a
# ╠═6ceb198e-edd3-4954-b1ff-beef33c3f205
# ╟─7a11e460-8d6f-454c-8fe6-33c59eeb4937
# ╟─ed7c40fe-f966-4afb-a962-896c9f109946
# ╟─a85b4f19-82e4-40d5-af9f-d5286578b1fb
# ╠═45828bb4-e9f5-46d5-8f48-88284f318cc4
# ╟─192c47a3-7202-4351-8638-ec49ecb901c5
# ╟─51370abb-f0fb-4ae0-b488-bf9fc776577c
# ╟─1287b479-cce9-4eb1-949b-9da7d0329c24
# ╟─199b45f6-1e63-4392-af6a-6a5ed83bf467
# ╟─9513f017-7905-495d-a7eb-6ca5927308dd
# ╟─1e9ab6b0-b25d-44ad-92ae-f12f92d91d5e
# ╟─1d90c687-7e67-43ed-b5bf-68ef9040dc95
# ╠═0518af44-878e-4052-b4d4-e7fb3c35efea
# ╟─ec2d40f7-1e06-414d-9a77-9e3489ba271c
# ╠═d3c95316-7ffb-11ef-1e2c-2934f89a2336
# ╠═31b74828-fdc7-4b04-8be0-ea44820f9555
# ╠═bb167a5e-b23a-4f05-9ba6-368a48f9c120
# ╠═3a1aa3d8-bea0-46cb-b07e-88e9484e75c6
# ╠═4d62900a-0810-49d1-8632-a9e7544f381b
# ╠═911a5ae8-5800-4d20-9d73-bcc7205d3501
# ╠═6da1efbe-e5a0-4376-b8ea-ed21f09da084
# ╠═23167971-4671-4f18-84df-72a7dc5938e1
# ╠═62ddeb91-e007-4407-b4dc-1b7392480781
# ╠═a77ccf6b-db67-4a07-833a-210afccc39e5
# ╠═e312d48d-9d8d-4f42-b134-7fe3023df270
# ╠═79703745-6c0e-4201-a58d-e75994fab4e4
# ╟─00000000-0000-0000-0000-000000000001
# ╟─00000000-0000-0000-0000-000000000002
